@@ -1,5 +1,5 @@
 use anyhow::Result;
-use jsona_openapi::parse;
+use jsona_openapi::from_str;
 use std::env;
 use std::fs::{self, OpenOptions};
 use std::io::prelude::*;
@@ -22,7 +22,7 @@ fn main() {
 fn run(input_file: &str, output_file: Option<&String>) -> Result<()> {
     let input = fs::read_to_string(input_file)
         .map_err(|e| anyhow::anyhow!("fail to read input file, {}", e))?;
-    let spec = parse(input.as_str()).map_err(|e| anyhow::anyhow!("fail to parse spec, {}", e))?;
+    let spec = from_str(input.as_str()).map_err(|e| anyhow::anyhow!("fail to parse spec, {}", e))?;
     let is_json = match output_file {
         Some(value) => value.ends_with(".json"),
         None => false,
